@@ -11,7 +11,6 @@ import types
 import werkzeug
 from opcode import HAVE_ARGUMENT, opmap, opname
 from types import CodeType
-from psycopg2 import OperationalError
 from .template import Tmpl
 import dateutil
 
@@ -342,10 +341,6 @@ def safe_eval(expr, globals_dict=None, locals_dict=None, mode="eval", nocopy=Fal
         return unsafe_eval(c, globals_dict, locals_dict)
     except werkzeug.exceptions.HTTPException:
         raise
-    except OperationalError:
-        # Do not hide PostgreSQL low-level exceptions, to let the auto-replay
-        # of serialized transactions work its magic
-        raise
     except ZeroDivisionError:
         raise
     except Exception as e:
